// ------------------------------------------------------------------------------------------------------------------------------------------------>
// THIS IS WHERE YOU DETERMINE THE SETTINGS FOR YOUR LIGHTS
// ------------------------------------------------------------------------------------------------------------------------------------------------>

    // SETUP INSTRUCTIONS 

    // EXPLANATION OF STATES
    // ------------------------------------------------------------------------------------------------------------------------------------------------>
    // Each light can respond to nine different conditions, or states. These are: 
    // - Channel 3 - Position 1
    // - Channel 3 - Position 2
    // - Channel 3 - Position 3
    // - Forward
    // - Reverse
    // - Stop
    // - Brake
    // - Right Turn
    // - Left Turn
    //
    // State Notes: 
    // - At the very least, you must plug in the Throttle channel. Steering and Channel 3 are optional
    // - If you do not plug in a steering channel, then obviously you will never encounter the Right Turn & Left Turn States
    // - If you do not plug in a third channel, the program will only use the values specified in Position 1 as the default. In other words, it acts
    //   as if you have a one-position switch that is always in Position 1
    // - If your third channel is only a two-position switch, the program will switch between Position 1 and Position 2
    // - If your third channel is a three position switch, you will be able to switch between all three positions
    // - For the third channel to operate correctly, and in fact, for all channels to operate correctly, you need to run through the Radio Setup once.

    // EXPLANATION OF SETTINGS
    // ------------------------------------------------------------------------------------------------------------------------------------------------>
    // For each light, you need to specify what will happen in each state - this is called the setting. The possible settings are: 
    // - ON
    // - OFF
    // - NA
    // - BLINK            Will blink at the rate set in the UserConfig.h
    // - FASTBLINK        Will blink at the fast rate set in UserConfig.h
    // - DIM              Will dim to the level set in UserConfig.h
    //
    // Settings Notes: 
    // - For the three positions determined by Channel 3, it is best to specify an explicit setting, in other words, you usually don't want them to be NA. 
    // - The opposite is true for the other states - if you don't want anything to happen during the Forward state for example, set it to NA, not OFF. Otherwise, your light will turn off when going forward. 
    // - Not every light can be dimmed. Look at the board to see which lights can be dimmed, they are marked with a star (*). In all hardware revisions so far, these have been lights 1-6. 
    // - If you specify a DIM setting for a light which isn't capable of it, the program will treat it as OFF instead. 
   
    // EXPLANATION OF SCHEMES
    // ------------------------------------------------------------------------------------------------------------------------------------------------>
    // A Scheme defines every setting for every light in every state. You may have multiple Schemes, the code defaults to 4 schemes. If you want more, add them 
    // below, but remember to also update the NumSchemes variable in AA_UserConfig.h.     
   
    // HOW TO SETUP YOUR LIGHTS
    // ------------------------------------------------------------------------------------------------------------------------------------------------>
    // Below you will see the lighting schemes. Each Scheme has a single row for each of the eight lights. The columns represent the states. The values
    // in the individual tables represent the settings for that light at that state. 
    // 
    // HERE IS AN EXAMPLE: 
    // 
    //     Mode 1     Mode 2     Mode 3     Forward     Reverse     Stop      Brake     Right Turn     Left Turn
    // ------------------------------------------------------------------------------------------------------------------------
    //  {  OFF,       DIM,       DIM,       NA,         NA,         NA,       ON,       NA,            BLINK            },        
    // 
    // This example would be typical for a left side brake light. It does the following: 
    // Mode 1     = OFF      - OFF when Channel 3 is in position 1
    // Mode 2     = DIM      - DIM when Channel 3 is in position 2
    // Mode 3     = DIM      - DIM when Channel 3 is in position 3
    // Forward    = NA       - no change when moving Forward
    // Reverse    = NA       - no change when in Reverse
    // Stop       = NA       - no change when Stopped
    // Brake      = ON       - light will turn full ON when braking
    // Right Turn = NA       - no change in right turn
    // Left Turn  = BLINK    - will blink when turning left


    // OK, YOU'RE READY. TRY NOT TO MESS UP THE LAYOUT. JUST CHANGE THE SETTINGS. REMEMBER THE POSSIBLE VALUES: 
    // ON, OFF, BLINK, FASTBLINK, DIM, NA

    prog_int16_t Schemes[NumSchemes][NumLights][NumStates] PROGMEM =
    {
        {
        //     SCHEME ONE - EXAMPLE PROVIDED
        //     Mode 1     Mode 2     Mode 3     Forward     Reverse     Stop      Brake     Right Turn     Left Turn
        // ------------------------------------------------------------------------------------------------------------------------
            {  OFF,       OFF,       ON,        NA,         NA,         NA,       NA,       NA,            NA            },         // Light 1    -- Headlight One - ON when Channel 3 is in Position 3
            {  OFF,       ON,        ON,        NA,         NA,         NA,       NA,       NA,            NA            },         // Light 2    -- Headlight Two - ON when Channel 3 is in Position 2 or 3
            {  OFF,       DIM,       DIM,       NA,         NA,         NA,       ON,       NA,            NA            },         // Light 3    -- Brake Light - ON when Braking, otherwise DIM if Channel 3 is in Position 2 or 3
            {  OFF,       DIM,       DIM,       NA,         NA,         NA,       NA,       BLINK,         NA            },         // Light 4    -- Right Turn Lights - BLINK when turning Right, otherwise DIM if Channel 3 is in Position 2 or 3
            {  OFF,       DIM,       DIM,       NA,         NA,         NA,       NA,       NA,            BLINK         },         // Light 5    -- Left Turn Lights - BLINK when turning Left, otherwise DIM if Channel 3 is in Position 2 or 3
            {  OFF,       OFF,       OFF,       NA,         ON,         NA,       NA,       NA,            NA            },         // Light 6    -- Reverse Lights - only turns on when moving in Reverse
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 7    --
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            }          // Light 8    --
        },
        {
        //     SCHEME TWO - EXAMPLE PROVIDED
        //     Mode 1     Mode 2     Mode 3     Forward     Reverse     Stop      Brake     Right Turn     Left Turn
        // ------------------------------------------------------------------------------------------------------------------------
            {  OFF,       OFF,       ON,        NA,         NA,         NA,       NA,       NA,            NA            },         // Light 1    -- Headlight One - ON when Channel 3 is in Position 3
            {  OFF,       ON,        ON,        NA,         NA,         NA,       NA,       NA,            NA            },         // Light 2    -- Headlight Two - ON when Channel 3 is in Position 2 or 3
            {  OFF,       DIM,       DIM,       NA,         NA,         ON,       ON,       NA,            NA            },         // Light 3    -- Brake Light - ON when Braking and when Stopped (drag brake). Otherwise DIM if Channel 3 is in Position 2 or 3
            {  OFF,       DIM,       DIM,       NA,         BLINK,      NA,       NA,       NA,            NA            },         // Light 4    -- Warn Lights - BLINK when in reverse, otherwise DIM if Channel 3 is in Position 2 or 3
            {  OFF,       DIM,       DIM,       NA,         BLINK,      NA,       NA,       NA,            NA            },         // Light 5    -- Warn Lights - BLINK when in Reverse, otherwise DIM if Channel 3 is in Position 2 or 3
            {  OFF,       OFF,       OFF,       NA,         ON,         NA,       NA,       NA,            NA            },         // Light 6    -- Reverse Lights - ON in Reverse
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 7    --
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            }          // Light 8    --
        },
        {
        //     SCHEME THREE - BLANK
        //     Mode 1     Mode 2     Mode 3     Forward     Reverse     Stop      Brake     Right Turn     Left Turn
        // ------------------------------------------------------------------------------------------------------------------------
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 1    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 2    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 3    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 4    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 5    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 6    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 7    --
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            }          // Light 8    --
        },
        {
        //     SCHEME FOUR - BLANK
        //     Mode 1     Mode 2     Mode 3     Forward     Reverse     Stop      Brake     Right Turn     Left Turn
        // ------------------------------------------------------------------------------------------------------------------------
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 1    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 2    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 3    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 4    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 5    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 6    -- 
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            },         // Light 7    --
            {  OFF,       OFF,       OFF,       NA,         NA,         NA,       NA,       NA,            NA            }          // Light 8    --
        },
    };




